==> nextcloud-31.0.10.tar.bz2: nextcloud/apps/circles/l10n/sl.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Skupine",
    "You created the team {circle}" : "Ustvarite skupino {circle}",
    "{author} created the team {circle}" : "{author} ustvari skupino {circle}",
    "You deleted {circle}" : "Izbrišete krog {circle}",
    "{author} deleted {circle}" : "{author} izbriše krog {circle}",
    "You removed {member} from {circle}" : "Iz kroga {circle} odstranite člana: {member}",
    "You joined {circle}" : "Pridružite se krogu {circle}",
    "{member} joined {circle}" : "{member} se pridruži krogu {circle}",
    "You accepted the invitation to join {circle}" : "Sprejmete povabilo v krog {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} sprejme vabilo za pristop v krog {circle}",
    "You added {member} as member to {circle}" : "V krog {circle} ste dodali osebo {member}",
    "You have been added as member to {circle} by {author}" : "{author} vas doda v krog {circle}",
    "{member} has been added as member to {circle} by {author}" : "Račun {member} je avtor {author} dodal v članstvo kroga {circle}.",
    "You added {external} to {circle}" : "V krog {circle} je dodana oseba {external}",
    "{external} has been added to {circle} by {author}" : "{external} je avtor {author} dodal v članstvo kroga {circle}.",
    "You accepted {member}'s request to join {circle}" : "Sprejeli ste prošnjo člana {member} za pristop v krog {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} sprejme vašo prošnjo za članstvo v krogu {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} sprejme prošnjo člana {member} za članstvo v krogu {circle}",
    "You left {circle}" : "Zapustite krog {circle}",
    "{member} left {circle}" : "{member} zapusti krog {circle}",
    "You declined the invitation to join {circle}" : "Zavrnete vabilo v krog {circle}",
    "{member} declined an invitation to join {circle}" : "{member} zavrne povabilo v krog {circle}",
    "You cancelled your request to join {circle}" : "Prekličete prošnjo za pristop v krog {circle}",
    "You have been removed from {circle} by {author}" : "{author} vas odstrani iz kroga {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} odstrani člana {member} iz kroga {circle}",
    "You removed {external} from {circle}" : "Odstranite zunanji račun {external} iz kroga {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} odstrani zunanji račun {external} iz kroga {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Članu {member} prekličete povabilo v krog {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} prekliče povabilo v krog {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} prekliče članu {member} povabilo v krog {circle}",
    "You dismissed {member}'s request to join {circle}" : "Zavrnete prošnjo člana {member} za pristop v krog {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} zavrne vašo prošnjo za članstvo v krogu {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} zavrne prošnjo člana {member} za članstvo v krogu  {circle}",
    "You invited {member} to join {circle}" : "Člana {member} povabite v krog {circle}",
    "You have been invited to join {circle} by {author}" : "{author} vas povabi v krog {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} povabi člana {member} v krog {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Spremenite vlogo člana {member} iz kroga {circle} v %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} spremeni vašo vlogo v krogu {circle} v %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} spremeni vlogo člana {member} iz kroga {circle} v %1$s",
    "You sent a request to join {circle}" : "Poslali ste prošnjo za pristop v krog {circle}",
    "{member} sent a request to join {circle}" : "{member} pošlje prošnjo za pristop v krog {circle}",
    "You are the new owner of {circle}" : "Postanete novi lastnik kroga {circle}",
    "{member} is the new owner of {circle}" : "{member} postane novi lastnik kroga {circle}",
    "Single" : "Enojni",
    "Personal" : "Osebni",
    "System" : "Sistem",
    "Visible" : "Vidno",
    "Open" : "Odpri",
    "Invite" : "Povabi",
    "Friends" : "Prijatelji",
    "Password protected" : "Zaščiteno z geslom",
    "No Owner" : "Ni lastnika",
    "Hidden" : "Skrito",
    "Backend" : "Ozadnji program",
    "Local" : "Krajevno",
    "Root" : "Koren",
    "Team invite" : "Skupinsko vabilo",
    "Federated" : "Zvezno",
    "Mount point" : "Priklopna točka",
    "Nextcloud Account" : "Račun Nextcloud",
    "Nextcloud Group" : "Skupina Nextcloud",
    "Email address" : "Elektronski naslov",
    "Contact" : "Stik",
    "Team" : "Skupina",
    "Nextcloud App" : "Program Nextcloud",
    "Member" : "Član",
    "Moderator" : "Moderator",
    "Admin" : "Skrbnik",
    "Owner" : "Lastnik",
    "%s shared »%s« with you." : "%s vam omogoča souporabo »%s«.",
    "%s shared »%s« with \"%s\"." : "%s omogoči souporabo »%s« z »%s«.",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s vam omogoči souporabo »%2$s«.\nPo elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s vam omogoči souporabo »%2$s«.\nPo elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.",
    "Password to access »%1$s« shared to you by %2$s" : "%2$s vam pošilja geslo za dostop do datoteke »%1$s«.",
    "Password to access »%s«" : "Geslo za dostop do »%s«",
    "It is protected with the following password:" : "Zaščiten je z geslom:",
    "%1$s via %2$s" : "%1$s prek %2$s",
    "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
    "Open »%s«" : "Odpri »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s vam omogoča souporabo več datotek.\nPo elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s vam omogoča souporabo več datotek. Po elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.",
    "Password to access files shared to you by %1$s" : "%1$s vam pošilja geslo za dostop do datoteke v souporabi.",
    "Password to access files" : "Geslo za dostop do datotek",
    "%s shared multiple files with \"%s\"." : "%s omogoči souporabo več datotek z uporabnikom »%s«.",
    "%s shared multiple files with you." : "%s vam omogoči souporabo več datotek.",
    "Boot up" : "Zaganjanje",
    "Nextcloud Initialization" : "Zaganjanje oblaka Nextcloud",
    "Circles App Initialization" : "Zaganjanje programa Krogi",
    "Fresh installation status" : "Stanje sveže namestitve",
    "Building Local Database" : "Poteka izgradnja krajevne podatkovne zbirke",
    "Testing Basic Circle Creation" : "Preizkušanje ustvarjanja osnovnega kroga",
    "Adding local users and moderators" : "Dodajanje krajevnih uporabnikov in moderatorjev",
    "Show all teams" : "Pokaži vse skupine",
    "Create a new team" : "Ustvari novo skupino",
    "Files" : "Datoteke",
    "This feature is not available for personal circles" : "Ta zmožnost za osebne kroge ni na voljo",
    "The team is not federated" : "Skupina ni povezana zvezno",
    "You cannot join this team" : "S skupini se ni mogoče povezati",
    "This member is not a moderator" : "Član ni moderator",
    "Insufficient privileges" : "Neustrezna dovoljenja",
    "This member does not exist" : "Član ne obstaja",
    "This member is the owner of the team" : "Član je lastnik te skupine",
    "Level cannot be changed for this type of member" : "Vloge za to vrsto člana ni mogoče spremeniti",
    "You are already a member of this circle" : "Ste že član tega kroga.",
    "You have been blocked from this circle" : "Iz tega kroga ste bili izločeni",
    "The account is already a member of this circle" : "Račun ima že potrjeno članstvo v krogu.",
    "The account has already been invited into this circle" : "Račun je že prejel vabilo za članstvo v krogu.",
    "Accept" : "Sprejmi",
    "Refuse" : "Zavrni",
    "%s" : "%s",
    "Personal team" : "Osebna skupina",
    "%s owned by %s" : "%s v lasti %s",
    "You have no permission to create a new team" : "Ni ustreznih dovoljenj za ustvarjanje skupin.",
    "%s shared a file with \"%s\"." : "%s omogoča souporabo datoteke z »%s«.",
    "%s shared a file with you." : "%s vam omogoča souporabo datoteke.",
    "Open %s" : "Odpri %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s vam omogoča souporabo vsebine.\nMorali bi že prejeti ločeno sporočilo s povezavo za dostop po elektronski pošti.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s vam omogoča souporabo vsebine. Morali bi že prejeti ločeno sporočilo s povezavo za dostop po elektronski pošti.",
    "Password to access content shared with you by %1$s" : "%1$s vam pošilja geslo za dostop do vsebine v souporabi.",
    "Password to access content" : "Geslo za dostop do vsebine",
    "This item is already shared with this team" : "Ta predmet je v tej skupini že v souporabi",
    "Bring cloud-users closer together." : "Potegnite uporabnike oblakov bliže skupaj.",
    "No teams found" : "Ni oblikovanih skupin",
    "Loading…" : "Poteka nalaganje …",
    "No files in here" : "V mapi ni datotek",
    "No entries found in this folder" : "V tej mapi ni datotek in podmap.",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno",
    "Shared to Circles" : "Souporaba v krogu"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-32.0.2.tar.bz2: nextcloud/apps/circles/l10n/sl.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Ustvarite skupino {circle}",
    "{author} created the team {circle}" : "{author} ustvari skupino {circle}",
    "You deleted {circle}" : "Izbrišete krog {circle}",
    "{author} deleted {circle}" : "{author} izbriše krog {circle}",
    "You removed {member} from {circle}" : "Iz kroga {circle} odstranite člana: {member}",
    "You joined {circle}" : "Pridružite se krogu {circle}",
    "{member} joined {circle}" : "{member} se pridruži krogu {circle}",
    "You accepted the invitation to join {circle}" : "Sprejmete povabilo v krog {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} sprejme vabilo za pristop v krog {circle}",
    "You added {member} as member to {circle}" : "V krog {circle} ste dodali osebo {member}",
    "You have been added as member to {circle} by {author}" : "{author} vas doda v krog {circle}",
    "{member} has been added as member to {circle} by {author}" : "Račun {member} je avtor {author} dodal v članstvo kroga {circle}.",
    "You added {external} to {circle}" : "V krog {circle} je dodana oseba {external}",
    "{external} has been added to {circle} by {author}" : "{external} je avtor {author} dodal v članstvo kroga {circle}.",
    "You accepted {member}'s request to join {circle}" : "Sprejeli ste prošnjo člana {member} za pristop v krog {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} sprejme vašo prošnjo za članstvo v krogu {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} sprejme prošnjo člana {member} za članstvo v krogu {circle}",
    "You left {circle}" : "Zapustite krog {circle}",
    "{member} left {circle}" : "{member} zapusti krog {circle}",
    "You declined the invitation to join {circle}" : "Zavrnete vabilo v krog {circle}",
    "{member} declined an invitation to join {circle}" : "{member} zavrne povabilo v krog {circle}",
    "You cancelled your request to join {circle}" : "Prekličete prošnjo za pristop v krog {circle}",
    "You have been removed from {circle} by {author}" : "{author} vas odstrani iz kroga {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} odstrani člana {member} iz kroga {circle}",
    "You removed {external} from {circle}" : "Odstranite zunanji račun {external} iz kroga {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} odstrani zunanji račun {external} iz kroga {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Članu {member} prekličete povabilo v krog {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} prekliče povabilo v krog {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} prekliče članu {member} povabilo v krog {circle}",
    "You dismissed {member}'s request to join {circle}" : "Zavrnete prošnjo člana {member} za pristop v krog {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} zavrne vašo prošnjo za članstvo v krogu {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} zavrne prošnjo člana {member} za članstvo v krogu  {circle}",
    "You invited {member} to join {circle}" : "Člana {member} povabite v krog {circle}",
    "You have been invited to join {circle} by {author}" : "{author} vas povabi v krog {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} povabi člana {member} v krog {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Spremenite vlogo člana {member} iz kroga {circle} v %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} spremeni vašo vlogo v krogu {circle} v %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} spremeni vlogo člana {member} iz kroga {circle} v %1$s",
    "You sent a request to join {circle}" : "Poslali ste prošnjo za pristop v krog {circle}",
    "{member} sent a request to join {circle}" : "{member} pošlje prošnjo za pristop v krog {circle}",
    "You are the new owner of {circle}" : "Postanete novi lastnik kroga {circle}",
    "{member} is the new owner of {circle}" : "{member} postane novi lastnik kroga {circle}",
    "Teams" : "Skupine",
    "Single" : "Enojni",
    "Personal" : "Osebni",
    "System" : "Sistem",
    "Visible" : "Vidno",
    "Open" : "Odpri",
    "Invite" : "Povabi",
    "Friends" : "Prijatelji",
    "Password protected" : "Zaščiteno z geslom",
    "No Owner" : "Ni lastnika",
    "Hidden" : "Skrito",
    "Backend" : "Ozadnji program",
    "Local" : "Krajevno",
    "Root" : "Koren",
    "Team invite" : "Skupinsko vabilo",
    "Federated" : "Zvezno",
    "Mount point" : "Priklopna točka",
    "Nextcloud Account" : "Račun Nextcloud",
    "Nextcloud Group" : "Skupina Nextcloud",
    "Email address" : "Elektronski naslov",
    "Contact" : "Stik",
    "Team" : "Skupina",
    "Nextcloud App" : "Program Nextcloud",
    "Member" : "Član",
    "Moderator" : "Moderator",
    "Admin" : "Skrbnik",
    "Owner" : "Lastnik",
    "%s shared »%s« with you." : "%s vam omogoča souporabo »%s«.",
    "%s shared »%s« with \"%s\"." : "%s omogoči souporabo »%s« z »%s«.",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s vam omogoči souporabo »%2$s«.\nPo elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s vam omogoči souporabo »%2$s«.\nPo elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.",
    "Password to access »%1$s« shared to you by %2$s" : "%2$s vam pošilja geslo za dostop do datoteke »%1$s«.",
    "Password to access »%s«" : "Geslo za dostop do »%s«",
    "It is protected with the following password:" : "Zaščiten je z geslom:",
    "%1$s via %2$s" : "%1$s prek %2$s",
    "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
    "Open »%s«" : "Odpri »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s vam omogoča souporabo več datotek.\nPo elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s vam omogoča souporabo več datotek. Po elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.",
    "Password to access files shared to you by %1$s" : "%1$s vam pošilja geslo za dostop do datoteke v souporabi.",
    "Password to access files" : "Geslo za dostop do datotek",
    "%s shared multiple files with \"%s\"." : "%s omogoči souporabo več datotek z uporabnikom »%s«.",
    "%s shared multiple files with you." : "%s vam omogoči souporabo več datotek.",
    "Boot up" : "Zaganjanje",
    "Nextcloud Initialization" : "Zaganjanje oblaka Nextcloud",
    "Circles App Initialization" : "Zaganjanje programa Krogi",
    "Fresh installation status" : "Stanje sveže namestitve",
    "Building Local Database" : "Poteka izgradnja krajevne podatkovne zbirke",
    "Adding local users and moderators" : "Dodajanje krajevnih uporabnikov in moderatorjev",
    "Show all teams" : "Pokaži vse skupine",
    "Create a new team" : "Ustvari novo skupino",
    "Files" : "Datoteke",
    "The team is not federated" : "Skupina ni povezana zvezno",
    "You cannot join this team" : "S skupini se ni mogoče povezati",
    "This member is not a moderator" : "Član ni moderator",
    "Insufficient privileges" : "Neustrezna dovoljenja",
    "This member does not exist" : "Član ne obstaja",
    "This member is the owner of the team" : "Član je lastnik te skupine",
    "Level cannot be changed for this type of member" : "Vloge za to vrsto člana ni mogoče spremeniti",
    "Accept" : "Sprejmi",
    "Refuse" : "Zavrni",
    "%s" : "%s",
    "Personal team" : "Osebna skupina",
    "%s owned by %s" : "%s v lasti %s",
    "You have no permission to create a new team" : "Ni ustreznih dovoljenj za ustvarjanje skupin.",
    "%s shared a file with \"%s\"." : "%s omogoča souporabo datoteke z »%s«.",
    "%s shared a file with you." : "%s vam omogoča souporabo datoteke.",
    "Open %s" : "Odpri %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s vam omogoča souporabo vsebine.\nMorali bi že prejeti ločeno sporočilo s povezavo za dostop po elektronski pošti.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s vam omogoča souporabo vsebine. Morali bi že prejeti ločeno sporočilo s povezavo za dostop po elektronski pošti.",
    "Password to access content shared with you by %1$s" : "%1$s vam pošilja geslo za dostop do vsebine v souporabi.",
    "Password to access content" : "Geslo za dostop do vsebine",
    "This item is already shared with this team" : "Ta predmet je v tej skupini že v souporabi",
    "Bring cloud-users closer together." : "Potegnite uporabnike oblakov bliže skupaj.",
    "No teams found" : "Ni oblikovanih skupin",
    "Loading…" : "Poteka nalaganje …",
    "No files in here" : "V mapi ni datotek",
    "No entries found in this folder" : "V tej mapi ni datotek in podmap.",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno",
    "Shared to Circles" : "Souporaba v krogu",
    "Testing Basic Circle Creation" : "Preizkušanje ustvarjanja osnovnega kroga",
    "This feature is not available for personal circles" : "Ta zmožnost za osebne kroge ni na voljo",
    "You are already a member of this circle" : "Ste že član tega kroga.",
    "You have been blocked from this circle" : "Iz tega kroga ste bili izločeni",
    "The account is already a member of this circle" : "Račun ima že potrjeno članstvo v krogu.",
    "The account has already been invited into this circle" : "Račun je že prejel vabilo za članstvo v krogu."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
